==> lxqt-panel-0.9.0.tar.xz: lxqt-panel-0.9.0/plugin-cpuload/translations/cpuload_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LxQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="119"/>
        <source>CPU load %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>العامّ</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>إظهار النَّصّ</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-cpuload/translations/cpuload_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="127"/>
        <source>CPU load %1%</source>
        <translation>الحمل على المعالج  %1٪</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>إعدادات الحمل على المعالج</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>عام</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>اعرض النص</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>فترة التحديث:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>ثا</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>اتجاه الشريط:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>عرض الشريط:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>أسفل لأعلى</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>أعلى لأسفل</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>يسار إلى يمين</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>يمين إلى يسار</translation>
    </message>
</context>
</TS>
